@@ -1,4 +1,4 @@
-# $Id: Subtitles.pm,v 1.15 2007/08/07 19:05:28 dk Exp $
+# $Id: Subtitles.pm,v 1.18 2008/12/03 17:04:29 dk Exp $
 package Subtitles;
 use strict;
 require Exporter;
@@ -6,7 +6,7 @@ use vars qw(@ISA @EXPORT @EXPORT_OK @codecs $VERSION);
 @ISA = qw(Exporter);
 @EXPORT = qw(codecs time2str);
 @EXPORT_OK = qw(codecs time2hms time2shms hms2time time2str);
-$VERSION = '1.00';
+$VERSION = '1.02';
 
 
 push @codecs, map { "Subtitles::Codec::$_" } qw( srt mdvd sub2 smi idx);
@@ -324,7 +324,7 @@ use vars qw(@ISA);
 
 sub match
 {
-	$_[1] =~ m/^(\d\d):(\d\d):(\d\d)\,(\d\d\d)\s*-->\s*(\d\d):(\d\d):(\d\d)\,(\d\d\d)/;
+	$_[1] =~ m/^(\d\d):(\d\d):(\d\d)[.,](\d\d\d)\s*-->\s*(\d\d):(\d\d):(\d\d)[.,](\d\d\d)/;
 }
 
 sub read
@@ -348,7 +348,7 @@ sub read
 			$stage++;
 		} elsif ( $stage == 1) {
 			die "Invalid timing at line $line\n" unless
-				m/^(\d\d):(\d\d):(\d\d)\,(\d\d\d)\s*-->\s*(\d\d):(\d\d):(\d\d)\,(\d\d\d)/;
+				m/^(\d\d):(\d\d):(\d\d)[.,](\d\d\d)\s*-->\s*(\d\d):(\d\d):(\d\d)[.,](\d\d\d)/;
 			push @{$sub->{from}}, Subtitles::hms2time( $1, $2, $3, $4);
 			push @{$sub->{to}},   Subtitles::hms2time( $5, $6, $7, $8); 
 			$stage++;
@@ -401,7 +401,7 @@ use vars qw(@ISA);
 
 sub match
 {
-	$_[1] =~ m/^{\d+}{\d*}/; 
+	$_[1] =~ m/^[{\[]\d+[}\]][{\[]\d*[}\]]/; 
 }
 
 sub read
@@ -418,7 +418,7 @@ sub read
 
 	for ( @$content) {
 		$line++;
-		unless ( m/^{(\d+)}{(\d*)}(.*)$/) {
+		unless ( m/^[{\[](\d+)[}\]][{\[](\d*)[}\]](.*)$/) {
 			warn "Invalid input at line $line\n";
 			next;
 		}
@@ -883,7 +883,7 @@ sub write
 
 =head1 NAME
 
-Subtitles - fix timing for subtitles in various text formats
+Subtitles - handle video subtitles in various text formats
 
 =head1 DESCRIPTION
 
@@ -893,7 +893,7 @@ loading, re-timing, and storing these subtitle files.  A command-line tool
 F<subs> for the same purpose and using C<Subtitles> interface is included in
 the distribution.
 
-The module supports C<srt>, C<sub>, C<smi> subtitle formats.
+The module supports C<srt>, C<sub>, C<smi>, and C<mdvd> subtitle formats.
 
 Time values are floats, in seconds with millisecond precision.
 
@@ -917,7 +917,7 @@ Time values are floats, in seconds with millisecond precision.
 	$sub-> transform( -120, 0.96);
 	$sub-> transform( -120, 0.96, 0, $sub-> length - 60);
 
-	# split for 2 parts
+	# split in 2
 	my ( $part1, $part2) = $sub-> split( $self-> length / 2);
 
 	# join back with 5-second gap 
